import { PageDataChange, PageModeChange } from "../control/events";
import { Relationship } from "../svi-datahub";
import { QueryMode } from "../svi-sand";
import { ControlContainer } from "../object/object-api";
import { PageModel, PageModelObjectData } from "../page-model/page-model-api";
import { SearchObject, SearchQuery } from "../search/client/client-search-api";
import { HandleType, MinMaxDates, TimeSliderContextMenuHideOptions, TimeSliderEventDates, TimeSliderRange, TimeSliderRangeChangedEvent } from "../time-slider";
export interface SearchAndSelectWithPreviewInputBindings {
    initialQuery?: string;
    additionalModes?: QueryMode[];
    objectTypeFilter?: string[];
}
export interface SearchAndSelectWithPreviewBindings extends SearchAndSelectWithPreviewInputBindings {
    onSearchItemSelected: (selectedItem: SearchObject | null) => void;
    onSearchItemDoubleClicked?: (selectedItem: SearchObject) => void;
}
export interface PageViewerApi {
    save: () => Promise<void>;
    isDirty: () => boolean;
    isValid: () => Promise<boolean>;
}
export interface PageBindings {
    docId?: string;
    docType?: string;
    eventName?: string;
    templateUuid?: string;
    showToolbar?: boolean;
    tempCreateId?: string;
    containerClass?: string;
    pageClass?: string;
    enableSheets?: string;
    pageModel?: PageModel;
    staticDocumentData?: Record<string, any>;
    initialCreateData?: Record<string, any>;
    setApi?: (api: PageViewerApi) => void;
    mainTab?: string;
    onDirty?: (isDirty: boolean) => void;
    onChange?: (change: PageDataChange | PageModeChange) => void;
}
export interface ControlCollectionBindings {
    controlContainer?: ControlContainer;
    pageModel?: PageModel;
    root?: boolean;
}
export interface RelationshipDetailsBindings {
    targetObjectTypeName: string;
    targetObjectTypeLabel: string;
    parentObjectTypeName: string;
    parentObjectTypeLabel: string;
    linkReasons: Relationship[];
    selectedItem?: {
        id: string;
        type: string;
    };
    newPageModel?: {
        model: PageModelObjectData;
    };
    onLinkReasonSelected: (linkReason: Relationship) => void;
    relationshipValues?: Record<string, any>;
    initialCreateData?: Record<string, any>;
    setApi?: (api: PageViewerApi) => void;
    onRelatedPageChange?: (change: PageDataChange | PageModeChange) => void;
    onRelationshipValuesChange?: (current: Record<string, any>, previous?: Record<string, any>) => void;
}
export interface SearchInputInputBindings {
    entityName: string;
    queryBuilderId?: string;
    showQueryBuilder?: boolean;
    queryText?: string;
    autoFocus?: boolean;
}
export interface SearchInputBindings extends SearchInputInputBindings {
    onSearch?: (model: SearchQuery) => void;
    onValueChange?: (val: string) => void;
}
export interface TimeSliderInputBindings {
    timeSliderId: string;
    timeSliderDates: TimeSliderEventDates;
    viewRange: TimeSliderRange;
    handleType?: HandleType;
    isReadOnly?: boolean;
    sliderWidth?: number;
    disableSwitchHandleType?: boolean;
    contextMenuHideOptions: TimeSliderContextMenuHideOptions;
    minMaxDates?: MinMaxDates;
}
export interface TimeSliderBindings extends TimeSliderInputBindings {
    rangeChangeEvent?: (rangeChangedEvent: TimeSliderRangeChangedEvent) => void;
    handleTypeChange?: (handleType: HandleType) => void;
    onLoad?: () => void;
    close?: () => void;
}
export declare type SviComponentBindings = ControlCollectionBindings | RelationshipDetailsBindings | SearchInputBindings | PageBindings | SearchAndSelectWithPreviewBindings | TimeSliderBindings;
