export declare const TAB_ACTIVE_EVENT = "SNG_TAB_ACTIVE";
export declare const CONTENT_PANE_RESIZE_EVENT = "SNG_CONTENT_PANE_RESIZE";
export declare enum PageEvents {
    ChildObjectOnSelect = "spb:ChildObjectSelect",
    CommentsOnShowEvent = "spb::Comments:onShow",
    DirtyStateChangeEvent = "spb::dirty-state-change",
    LoadDocumentEvent = "spb::page-load-all",
    ModeChangeEvent = "spb::page-mode-change",
    ModelChangeEvent = "spb::page-model-change",
    PanelOpenEvent = "spb::sliding-panel-open",
    RefreshAttachmentsGrid = "spb::refreshAttachmentsGrid",
    RefreshPageEvent = "spb::refreshPage",
    SelectAttachmentEvent = "spb::Highlighting:SelectAttachment",
    SelectChildObjectEvent = "spb::Highlighting:SelectChildObject",
    SelectCommentEvent = "spb::Highlighting:SelectComment",
    SelectNodeEvent = "spb::selectNode",
    UpdateSubDocumentTypeEvent = "spb::updateSubDocumentType",
    TabSelectedEvent = "spb::tabSelected",
    VisitAllTabs = "spb::mark-all-tabs-visited",
    MaskToggleEvent = "spb::mask-toggle",
    MaskAllEvent = "spb::mask-all"
}
export interface Subscription {
    unsubscribe(): void;
}
/**
 * This API provides the  details and functionality associated with publishing and subscribing to events.
 * Accessed from the window at window.sas.vi.event.
 */
export interface EventApi {
    /**
     * @method
     * @description Publishes an event for subscribers to consume.
     * @param eventName {string} Name of the event to publish.
     * @param [payload] {any} Data passed to all subscribers.
     */
    publish(eventName: string, payload?: any): void;
    /**
     * @method
     * @description Subscribes to an event and registers a function to be called on any future published events.
     * If the eventName does not exist, it is created.
     * @param eventName {string} Name of the event to subscribe to.
     * @param {EventApi~subscriptionCallback} Function invoked when the subscription is triggered by an event.
     * Has access to the event's payload.
     * @returns The subscription being made to the event.
     */
    subscribe(eventName: string, observer: (payload: any) => void): Subscription | undefined;
    /**
     * @method
     * @description Unsubscribe from a given subscription and stop listening for events.
     * @param subscription {Subscription} Subscription to stop.
     */
    unsubscribe(subscription: Subscription): void;
}
/**
 * Callback function executed when subscription is triggered by an event.
 * @callback EventApi~subscriptionCallback
 * @param payload {any} Payload of the subscription.
 * @returns {void}
 */
