/**
 * This API is used for the localization methods.
 * Accessed from the window at window.sas.vi.localization.
 */
export interface LocalizationApi {
    /**
     * @method
     * @description Returns the MomentJS format string based on locale.
     * @param [showTime=true] {boolean} Checks whether or not to include time (in 12 hour format).
     * @returns The localized date time format as a string.
     */
    getLocalizedDateTimeFormat(showTime?: boolean): string;
    /**
     * @method
     * @description Gets the application locale in BCP 47 format.
     * @returns The current application locale.
     */
    getLocale(): string;
    /**
     * @method
     * @description Gets the application display direction.
     * This is either "ltr" for left-to-right display locales, or "rtl" for right-to-left locales.
     * @returns The current application display direction.
     */
    getDirection(): "ltr" | "rtl";
}
